actionIdxDf: Info about the actions in the HMDP model under consideration.

View source: R/convert.R

actionIdxDfR Documentation

Info about the actions in the HMDP model under consideration.

Description

Info about the actions in the HMDP model under consideration.

Usage

actionIdxDf(prefix = "", file = "actionIdx.bin", labels = "actionIdxLbl.bin")

Arguments

prefix

A character string with the prefix added to til file(s).

file

The HMDP binary file containing the description under consideration.

labels

The HMDP binary file containing the labels under consideration.

Value

A data frame with the same columns as in actionIdxMat plus another column containing the labels.


MDP2 documentation built on June 13, 2026, 1:08 a.m.