actionInfo: Info about the actions in the HMDP model under consideration.

View source: R/convert.R

actionInfoR Documentation

Info about the actions in the HMDP model under consideration.

Description

Info about the actions in the HMDP model under consideration.

Usage

actionInfo(
  prefix = "",
  file = "actionIdx.bin",
  weightFile = "actionWeight.bin",
  transPrFile = "transProb.bin",
  labels = "actionIdxLbl.bin"
)

Arguments

prefix

A character string with the prefix added to til file(s).

file

The HMDP binary file containing the description under consideration.

weightFile

The HMDP binary file containing the action costs.

transPrFile

The HMDP binary file containing the transition probabilities.

labels

The HMDP binary file containing the labels under consideration.

Value

A matrix with columns from actionIdxMat, actionCostMat and transProbMat if labels is NULL. If labels not are NULL then a data frame are returned with a label column too.


MDP2 documentation built on June 13, 2026, 1:08 a.m.