checkWDurIdx: Internal function. Check if the indexes given are okay....

checkWDurIdxR Documentation

Internal function. Check if the indexes given are okay. Should not be used except you know what you are doing

Description

Internal function. Check if the indexes given are okay. Should not be used except you know what you are doing

Usage

.checkWDurIdx(iW, iDur, wLth)

Arguments

iW

Index of the weight we want to optimize.

iDur

Index of the duration/time.

wLth

Number of weights in the model.

Value

Nothing.


MDP2 documentation built on June 13, 2026, 1:08 a.m.