checkWIdx: Internal function. Check if the index of the weight is okay....

checkWIdxR Documentation

Internal function. Check if the index of the weight is okay. Should not be used except you know what you are doing

Description

Internal function. Check if the index of the weight is okay. Should not be used except you know what you are doing

Usage

.checkWIdx(iW, wLth)

Arguments

iW

Index of the weight we want to optimize.

wLth

Number of weights in the model.

Value

Nothing.


MDP2 documentation built on June 13, 2026, 1:08 a.m.