getSteadyStatePr: Calculate the steady state transition probabilities for the...

View source: R/mdp.R

getSteadyStatePrR Documentation

Calculate the steady state transition probabilities for the founder process (level 0).

Description

Assume that we consider an ergodic/irreducible time-homogeneous Markov chain specified using a policy in the MDP.

Usage

getSteadyStatePr(mdp, getLog = FALSE)

Arguments

mdp

The MDP loaded using loadMDP().

getLog

Output log text.

Value

A vector with steady state probabilities for all the states at the founder level.


MDP2 documentation built on June 13, 2026, 1:08 a.m.