getWIdx: Return the index of a weight in the model. Note that index...

View source: R/mdp.R

getWIdxR Documentation

Return the index of a weight in the model. Note that index always start from zero (C++ style), i.e. the first weight, the first state at a stage etc has index 0.

Description

Return the index of a weight in the model. Note that index always start from zero (C++ style), i.e. the first weight, the first state at a stage etc has index 0.

Usage

getWIdx(mdp, wLbl)

Arguments

mdp

The MDP loaded using loadMDP().

wLbl

The label/string of the weight.

Value

The index (integer).


MDP2 documentation built on June 13, 2026, 1:08 a.m.