| actionIdxDf | R Documentation |
Info about the actions in the HMDP model under consideration.
actionIdxDf(prefix = "", file = "actionIdx.bin", labels = "actionIdxLbl.bin")
prefix |
A character string with the prefix added to til file(s). |
file |
The HMDP binary file containing the description under consideration. |
labels |
The HMDP binary file containing the labels under consideration. |
A data frame with the same columns as in
actionIdxMat plus another column containing the labels.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.