| actionWeightMat | R Documentation |
Info about the weights of the actions in the HMDP model under consideration.
actionWeightMat(
prefix = "",
file = "actionWeight.bin",
labels = "actionWeightLbl.bin"
)
prefix |
A character string with the prefix added to til file(s). |
file |
The HMDP binary file containing the description under consideration. |
labels |
The HMDP binary file containing the labels under consideration. |
A matrix with columns (aId, ...) where
aId is the action row id and ... are the weights of the action.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.