| binaryActionWriter | R Documentation |
binaryMDPWriter
and that the id of the states is known (can be retrieved using e.g. stateIdxDf).Binary files are efficient for storing large models. Compared to the HMP (XML) format the binary files use less storage space and loading the model is faster.
binaryActionWriter(
prefix = "",
binNames = c("actionIdx.bin", "actionIdxLbl.bin", "actionWeight.bin",
"actionWeightLbl.bin", "transProb.bin", "transWeight.bin", "transWeightLbl.bin"),
append = TRUE
)
prefix |
A character string with the prefix added to |
binNames |
A character vector of length 5 giving the names of the binary files storing the model. |
append |
Logical indicating whether should keep the currents actions (default - TRUE) defined or delete them and start over (FALSE). |
The returned writer exposes these functions:
setWeights(labels, ...): sets the labels of the weights used in the
actions. labels is a vector of label names. ... is currently ignored.
Call this before building the model.
addAction(label = NULL, sIdx, weights, prob, ...): adds an action. sIdx
is the id of the state defining the action. weights must be a vector of
action weights. prob is a matrix (sIdx, pr) where the first column
contains the id of the transition state; see the description of
actionIdx.bin below, where scope is assumed to be 3. ... is currently
ignored.
endAction(): ends an action.
closeWriter(): closes the writer. Call this when the model description is
finished.
Five binary files are created:
actionIdx.bin: integers defining all actions in the format
sIdx scope idx scope idx scope idx -1 sIdx scope idx scope idx -1 sIdx scope -1 ....
sIdx corresponds to the index or line number in stateIdx.bin, starting
from 0. The following (scope, idx) pairs indicate possible transitions.
Scope can take four values:
2: a transition to a child process, at stage zero in the child process.
1: a transition to the next stage in the current process.
0: a transition to the next stage in the father process.
3: a transition to a state specified by its state sIdx.
For example, if scope = 1 and idx = 2, the transition is to state
number 3 at the next stage in the current process. If scope = 3 and
idx = 5, the transition is to the state specified at line 6 in
stateIdxLbl.bin. This is useful when considering shared child processes.
actionIdxLbl.bin: character data in the format aIdx label aIdx label ....
Here aIdx corresponds to the index or line number in actionIdx.bin,
starting from 0. No delimiter is used.
actionWeight.bin: doubles containing action weights in the format
"c1 c2 c3 c1 c2 c3 ...", assuming three weights for each action.
actionWeightLbl.bin: character data containing the weight labels in the
format label1 label2 label3, assuming three weights for each action.
transProb.bin: doubles containing the transition probabilities defined in
actionIdx.bin. The format is "p1 p2 p3 -1 p1 -1 p1 p2 -1 ...". Here
-1 indicates that a new action is considered.
A list of functions.
Note all indexes are starting from zero (C/C++ style).
## Use temp dir
wd <- setwd(tempdir())
# Create a small HMDP with two levels
w<-binaryMDPWriter()
w$setWeights(c("Duration","Net reward","Items"))
w$process()
w$stage()
w$state(label="M0")
w$action(label="A0",weights=c(0,0,0),prob=c(2,0,1))
w$process()
w$stage()
w$state(label="D")
w$action(label="A0",weights=c(0,0,1),prob=c(1,0,0.5,1,1,0.5))
w$endAction()
w$endState()
w$endStage()
w$stage()
w$state(label="C0")
w$action(label="A0",weights=c(0,0,0),prob=c(1,0,1))
w$endAction()
w$action(label="A1",weights=c(1,2,1),prob=c(1,0,0.5,1,1,0.5))
w$endAction()
w$endState()
w$state(label="C1")
w$action(label="A0",weights=c(0,0,0),prob=c(1,0,1))
w$endAction()
w$action(label="A1",weights=c(1,2,1),prob=c(1,0,0.5,1,1,0.5))
w$endAction()
w$endState()
w$endStage()
w$stage()
w$state(label="C0")
w$action(label="A0",weights=c(1,4,0),prob=c(0,0,1))
w$endAction()
w$endState()
w$state(label="C1")
w$action(label="A0",weights=c(1,4,0),prob=c(0,0,1))
w$endAction()
w$endState()
w$endStage()
w$endProcess()
w$endAction()
w$action(label="A1",weights=c(0,0,0),prob=c(2,0,1))
w$process()
w$stage()
w$state(label="D")
w$action(label="A0",weights=c(0,0,1),prob=c(1,0,1))
w$endAction()
w$endState()
w$endStage()
w$stage()
w$state(label="C0")
w$action(label="A0",weights=c(0,0,0),prob=c(1,0,1))
w$endAction()
w$action(label="A1",weights=c(1,2,1),prob=c(1,0,0.5,1,1,0.5))
w$endAction()
w$endState()
w$endStage()
w$stage()
w$state(label="C0")
w$action(label="A0",weights=c(1,4,0),prob=c(0,0,1))
w$endAction()
w$endState()
w$state(label="C1")
w$action(label="A0",weights=c(1,4,0),prob=c(0,0,1))
w$endAction()
w$action(label="A1",weights=c(0,10,5),prob=c(0,0,0.5,0,1,0.5))
w$endAction()
w$endState()
w$endStage()
w$endProcess()
w$endAction()
w$endState()
w$state(label="M1")
w$action(label="A0",weights=c(0,0,0),prob=c(2,0,1))
w$process()
w$stage()
w$state(label="D")
w$action(label="A0",weights=c(0,0,1),prob=c(1,0,0.5,1,1,0.5))
w$endAction()
w$endState()
w$endStage()
w$stage()
w$state(label="C0")
w$action(label="A0",weights=c(0,0,0),prob=c(1,0,1))
w$endAction()
w$endState()
w$state(label="C1")
w$action(label="A0",weights=c(0,0,0),prob=c(1,0,1))
w$endAction()
w$endState()
w$endStage()
w$stage()
w$state(label="C0")
w$action(label="A0",weights=c(1,4,0),prob=c(0,0,1))
w$endAction()
w$endState()
w$state(label="C1")
w$action(label="A0",weights=c(1,4,0),prob=c(0,0,1))
w$endAction()
w$endState()
w$endStage()
w$endProcess()
w$endAction()
w$endState()
w$endStage()
w$endProcess()
w$closeWriter()
## Info about the binary files (don't have to load the model first)
getBinInfoStates()
getBinInfoActions()
## reset working dir
setwd(wd)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.