| convertHMP2Binary | R Documentation |
The function simply parse the hmp file and create binary files using
the binaryMDPWriter().
convertHMP2Binary(file, prefix = "", getLog = TRUE)
file |
The name of the HMP file (e.g. |
prefix |
A character string with the prefix which will be added to the binary files. |
getLog |
Output log text. |
NULL (invisible).
Note all indexes are starting from zero (C/C++ style).
binaryMDPWriter().
## Set working dir
fDir <- system.file("models", package = "MDP2")
wd <- setwd(tempdir())
## Convert the machine example to a hmp file
prefix1 <- paste0(fDir,"/machine1_")
getBinInfoStates(prefix1)
convertBinary2HMP(prefix1, duration = NULL, out = "machine1_converted.hmp")
# have a look at the hmp file
cat(readr::read_file("machine1_converted.hmp"))
## Convert the machine example hmp file to binary files
convertHMP2Binary(file = paste0(fDir,"/machine1.hmp"), prefix = "machine_cov_")
getBinInfoStates(prefix = "machine_cov_")
## Convert the machine example with a single dummy node to a hmp file
#convertBinary2HMP("machine2_") # error since using scope = 3 not supported in hmp files
## Reset working dir
setwd(wd)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.