| getRPO | R Documentation |
The RPO is defined as the difference between
the weight of the state when using action iA and the maximum
weight of the node when using another predecessor different from iA.
getRPO(
mdp,
w,
iA,
sId = ifelse(mdp$timeHorizon >= Inf, mdp$founderStatesLast + 1,
1):ifelse(mdp$timeHorizon >= Inf, mdp$states + mdp$founderStatesLast, mdp$states) - 1,
criterion = "expected",
dur = "",
rate = 0,
rateBase = 1,
discountFactor = NULL,
g = 0,
objective = c("max", "min"),
discountMethod = "continuous",
stateStr = TRUE
)
mdp |
The MDP loaded using |
w |
The label of the weight we calculate RPO for. |
iA |
The action index we calculate the RPO with respect to (same size as |
sId |
Vector of id's of the states we want to retrieve. |
criterion |
The Bellman operator shortcut. If |
dur |
The label of the duration/time such that discount rates can be calculated. |
rate |
The interest rate. |
rateBase |
The time-horizon the rate is valid over. |
discountFactor |
The discount rate for one time unit. If specified |
g |
The optimal gain (g) calculated (used if |
objective |
Optimize by maximizing ( |
discountMethod |
Either 'continuous' or 'discrete', corresponding to discount factor |
stateStr |
Output the state string. |
The RPO (matrix/data frame).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.