| getSteadyStatePr | R Documentation |
Assume that we consider an ergodic/irreducible time-homogeneous Markov chain specified using a policy in the MDP.
getSteadyStatePr(mdp, getLog = FALSE)
mdp |
The MDP loaded using |
getLog |
Output log text. |
A vector with steady state probabilities for all the states at the founder level.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.