| runPolicyIteAve | R Documentation |
The policy can afterwards be received using functions getPolicy and getPolicyW.
runPolicyIteAve(
mdp,
w,
dur,
maxIte = 100,
objective = c("max", "min"),
getLog = TRUE
)
mdp |
The MDP loaded using |
w |
The label of the weight we optimize. |
dur |
The label of the duration/time such that discount rates can be calculated. |
maxIte |
Max number of iterations. If the model does not satisfy the unichain assumption the algorithm may loop. |
objective |
Optimize by maximizing ( |
getLog |
Output the log messages. |
The optimal gain (g) calculated.
getPolicy().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.