| runPolicyIteDiscount | R Documentation |
The policy can afterwards be received using functions getPolicy and getPolicyW.
runPolicyIteDiscount(
mdp,
w,
dur,
rate = 0,
rateBase = 1,
discountFactor = NULL,
maxIte = 100,
discountMethod = "continuous",
objective = c("max", "min"),
getLog = TRUE
)
mdp |
The MDP loaded using |
w |
The label of the weight we optimize. |
dur |
The label of the duration/time such that discount rates can be calculated. |
rate |
The interest rate. |
rateBase |
The time-horizon the rate is valid over. |
discountFactor |
The discount rate for one time unit. If specified |
maxIte |
Max number of iterations. If the model does not satisfy the unichain assumption the algorithm may loop. |
discountMethod |
Either 'continuous' or 'discrete', corresponding to discount factor |
objective |
Optimize by maximizing ( |
getLog |
Output the log messages. |
Nothing.
getPolicy().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.